
#ifndef _C1_kl20_
#define _C1_kl20_

#ifdef __cplusplus
extern "C" {
#endif

extern EIF_BOOLEAN F20_340(EIF_REFERENCE, EIF_REFERENCE, EIF_REFERENCE);
extern void EIF_Minit20(void);

#ifdef __cplusplus
}
#endif

#endif
